@@ -21,8 +21,4 @@ from .hardware_information import HardwareInformation
 from .operating_system import OperatingSystem
 from .runtime_environment import RuntimeEnvironment
 
-__all__ = [
-    "HardwareInformation",
-    "OperatingSystem",
-    "RuntimeEnvironment",
-]
+__all__ = ["HardwareInformation", "OperatingSystem", "RuntimeEnvironment"]
