@@ -864,12 +864,15 @@ class OpenShift:
             "memory"
         ]
 
-        template_parameters["THOTH_SEND_MESSAGES"] = str(
-            int(specification.get("send_messages", True))
-        )
-        template_parameters["THOTH_FORCE_SYNC"] = str(
-            int(specification.get("force_sync", False))
-        )
+        if specification.get("send_messages") is not None:
+            template_parameters["THOTH_SEND_MESSAGES"] = str(
+                int(specification["send_messages"])
+            )
+
+        if specification.get("force_sync") is not None:
+            template_parameters["THOTH_FORCE_SYNC"] = str(
+                int(specification["force_sync"])
+            )
 
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
         workflow_parameters["dockerfile"] = dockerfile
@@ -926,6 +929,7 @@ class OpenShift:
         packages: str,
         *,
         indexes: Optional[List[str]] = None,
+        dependency_indexes: Optional[List[str]] = None,
         force_sync: bool = False,
         debug: bool = False,
         transitive: bool = False,
@@ -937,6 +941,7 @@ class OpenShift:
                 packages=packages,
                 solver=solver_name,
                 indexes=indexes,
+                dependency_indexes=dependency_indexes,
                 force_sync=force_sync,
                 debug=debug,
                 transitive=transitive,
@@ -952,6 +957,7 @@ class OpenShift:
         solver: str,
         *,
         indexes: Optional[List[str]] = None,
+        dependency_indexes: Optional[List[str]] = None,
         force_sync: bool = False,
         debug: bool = False,
         transitive: bool = True,
@@ -970,6 +976,9 @@ class OpenShift:
             "THOTH_SOLVER_PACKAGES": packages.replace("\n", "\\n"),
             "THOTH_SOLVER_NO_TRANSITIVE": int(not transitive),
             "THOTH_SOLVER_INDEXES": ",".join(indexes) if indexes else "",
+            "THOTH_SOLVER_DEPENDENCY_INDEXES": ",".join(dependency_indexes)
+            if dependency_indexes
+            else "",
             "THOTH_FORCE_SYNC": int(force_sync),
             "THOTH_LOG_SOLVER": "DEBUG" if debug else "INFO",
         }
@@ -1072,6 +1081,36 @@ class OpenShift:
             },
         )
 
+    def schedule_sync_job(
+        self,
+        document_type: Optional[str],
+        force_sync: bool = False,
+        graceful: bool = True,
+        job_id: Optional[str] = None,
+    ) -> Optional[str]:
+        """Schedule graph sync for specific document id."""
+        if not self.middletier_namespace:
+            raise ConfigurationError(
+                "Unable to schedule graph-sync without middletier namespace being set"
+            )
+
+        sync_id = job_id or self.generate_id("sync")
+        template_parameters = {
+            "THOTH_SYNC_JOB_ID": sync_id,
+            "THOTH_DOCUMENT_TYPE": document_type,
+            "THOTH_SYNC_GRACEFUL": graceful,
+            "THOTH_SYNC_FORCE_SYNC": force_sync,
+        }
+        workflow_parameters = self._assign_workflow_parameters_for_ceph()
+
+        return self._schedule_workflow(
+            workflow=self.workflow_manager.submit_sync_job,
+            parameters={
+                "template_parameters": template_parameters,
+                "workflow_parameters": workflow_parameters,
+            },
+        )
+
     def create_config_map(
         self,
         configmap_name: str,
@@ -1467,14 +1506,13 @@ class OpenShift:
 
     def schedule_mi_workflow(
         self,
+        create_knowledge: Optional[bool] = False,
         repository: Optional[str] = None,
         entities: Optional[str] = None,
         knowledge_path: Optional[str] = None,
         mi_merge_path: Optional[str] = None,
         mi_used_for_thoth: Optional[bool] = False,
         mi_merge: Optional[bool] = False,
-        *,
-        job_id: Optional[str] = None,
     ) -> Optional[str]:
         """Schedule Meta-information Indicators Workflow.
 
@@ -1482,9 +1520,23 @@ class OpenShift:
         :param entities:Optional[str]: Meta-information Indicator Entities that will be inspected
                                        multiple entities are in form of Foo,Bar,...
         """
-        workflow_id = job_id or self.generate_id("mi")
+        prefixes = []
+        if repository:
+            # '_' is only allowed character for repository name that is not accepted in workflow name
+            prefixes.append("-".join(repository.replace("_", "-").split("/")))
+        if create_knowledge:
+            prefixes.append("analysis")
+        if mi_merge:
+            prefixes.append("merge")
+        if mi_used_for_thoth:
+            prefixes.append("thoth")
+
+        workflow_name = "-".join(prefixes)
+        workflow_id = self.generate_id(workflow_name)
+
         template_parameters = {
             "WORKFLOW_ID": workflow_id,
+            "CREATE_KNOWLEDGE": "1" if create_knowledge else "0",
             "REPOSITORY": repository,
             "ENTITIES": entities,
             "KNOWLEDGE_PATH": knowledge_path or "",
@@ -1757,37 +1809,37 @@ class OpenShift:
 
         if memory_spec.endswith("E"):
             parsed = float(memory_spec[:-1])
-            return parsed * 1000 ** 6
+            return parsed * 1000**6
         elif memory_spec.endswith("P"):
             parsed = float(memory_spec[:-1])
-            return parsed * 1000 ** 5
+            return parsed * 1000**5
         elif memory_spec.endswith("T"):
             parsed = float(memory_spec[:-1])
-            return parsed * 1000 ** 4
+            return parsed * 1000**4
         elif memory_spec.endswith("G"):
             parsed = float(memory_spec[:-1])
-            return parsed * 1000 ** 3
+            return parsed * 1000**3
         elif memory_spec.endswith("M"):
             parsed = float(memory_spec[:-1])
-            return parsed * 1000 ** 2
+            return parsed * 1000**2
         elif memory_spec.endswith("K"):
             parsed = float(memory_spec[:-1])
             return parsed * 1000
         elif memory_spec.endswith("Ei"):
             parsed = float(memory_spec[:-2])
-            return parsed * 1024 ** 6
+            return parsed * 1024**6
         elif memory_spec.endswith("Pi"):
             parsed = float(memory_spec[:-2])
-            return parsed * 1024 ** 5
+            return parsed * 1024**5
         elif memory_spec.endswith("Ti"):
             parsed = float(memory_spec[:-2])
-            return parsed * 1024 ** 4
+            return parsed * 1024**4
         elif memory_spec.endswith("Gi"):
             parsed = float(memory_spec[:-2])
-            return parsed * 1024 ** 3
+            return parsed * 1024**3
         elif memory_spec.endswith("Mi"):
             parsed = float(memory_spec[:-2])
-            return parsed * 1024 ** 2
+            return parsed * 1024**2
         elif memory_spec.endswith("Ki"):
             parsed = float(memory_spec[:-2])
             return parsed * 1024
