@@ -26,7 +26,6 @@ from pathlib import Path
 from typing import Any
 from typing import Dict
 from typing import List
-from typing import Mapping
 from typing import Optional
 from typing import Union
 
@@ -172,12 +171,12 @@ class WorkflowManager:
     def __init__(
         self,
         openshift: Optional[OpenShift] = None,
-        openshift_config: Optional[Mapping[str, str]] = None,
+        openshift_config: Optional[Dict[str, str]] = None,
     ):
         """Initialize WorkflowManager instance."""
         ocp_config = openshift_config or {}
 
-        self.openshift = openshift or OpenShift(**ocp_config)
+        self.openshift = openshift or OpenShift(**ocp_config)  # type: ignore
         self.api = client.V1alpha1Api(client.ApiClient(self.openshift.configuration))
 
     def get_workflow_template(
@@ -861,6 +860,27 @@ class WorkflowManager:
 
         return workflow_id
 
+    def submit_sync_job(
+        self,
+        template_parameters: Optional[Dict[str, str]] = None,
+        workflow_parameters: Optional[Dict[str, Any]] = None,
+    ) -> Optional[str]:
+        """Submit graph-sync workflow."""
+        if not self.openshift.middletier_namespace:
+            raise ConfigurationError("Middletier namespace was not provided.")
+
+        template_parameters = template_parameters or {}
+        workflow_parameters = workflow_parameters or {}
+
+        workflow_id: Optional[str] = self.submit_workflow_from_template(
+            self.openshift.middletier_namespace,
+            label_selector="template=sync",
+            template_parameters=template_parameters,
+            workflow_parameters=workflow_parameters,
+            workflow_namespace=self.openshift.graph_namespace,
+        )
+        return workflow_id
+
     def submit_graph_sync(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
